#
# spec file for package libimobiledevice
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libimobiledevice-1_0-6
Name:           libimobiledevice
VCS: https://src.suse.de/SLFO-pool/libimobiledevice#0903d46cca2484a80e9668f08d772d973c324d02690d18f88515c541dfb006f6
Version:        1.3.0+190git.20230705
Release:        160000.2.2
Summary:        Native protocols library for iOS devices
License:        LGPL-2.1-or-later
URL:            https://www.libimobiledevice.org
Source:         %{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  (python3-Cython >= 0.17 with python3-Cython < 3)
BuildRequires:  python3-plist
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(libimobiledevice-glue-1.0) >= 1.0.0
BuildRequires:  pkgconfig(libplist-2.0) >= 2.3.0
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libusbmuxd-2.0) >= 2.0.2
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools

%description
libimobiledevice is a software library that talks the protocols to support
iOS devices. It does not depend on any existing libraries from Apple.

%package -n %{libname}
Summary:        Native protocols library for iOS devices
License:        LGPL-2.1-or-later

%description -n %{libname}
libimobiledevice is a software library that talks the protocols to support
iOS devices. It does not depend on any existing libraries from Apple.

%package devel
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later
Requires:       %{libname} = %{version}
Requires:       pkgconfig(libplist-2.0)

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n imobiledevice-tools
Summary:        Tools using %{name} for iOS devices
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Requires:       %{libname} = %{version}
Provides:       %{name}-tools = %{version}
Obsoletes:      %{name}-tools < %{version}

%description -n imobiledevice-tools
libimobiledevice is a software library that talks the protocols to support
iOS devices. It does not depend on any existing libraries from Apple.

%package -n python3-imobiledevice
Summary:        Python bindings for %{name}
License:        LGPL-2.1-or-later
Requires:       %{libname} = %{version}
Requires:       python3-plist >= 1.11

%description -n python3-imobiledevice
Contains Python bindings for developing applications that use %{name}.

%prep
%setup -q
sed -i -e '/Requires:/d' src/%{name}-1.0.pc.in
sed -i -e 's/-L${libdir}//' src/%{name}-1.0.pc.in

%build
autoreconf -fvi
%configure \
  --disable-silent-rules \
  --disable-static \
  PYTHON=%{_bindir}/python3 PACKAGE_VERSION=%{version}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING.LESSER
%{_libdir}/%{name}-1.0.so.6*

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{name}-1.0.so
%{_libdir}/pkgconfig/%{name}-1.0.pc

%files -n imobiledevice-tools
%doc AUTHORS NEWS README.md
%{_bindir}/idevice_id
%{_bindir}/idevicebtlogger
%{_bindir}/idevicecrashreport
%{_bindir}/idevicedevmodectl
%{_bindir}/idevicepair
%{_bindir}/ideviceinfo
%{_bindir}/idevicesyslog
%{_bindir}/idevicebackup
%{_bindir}/idevicebackup2
%{_bindir}/idevicedebug
%{_bindir}/idevicedebugserverproxy
%{_bindir}/idevicediagnostics
%{_bindir}/ideviceimagemounter
%{_bindir}/idevicename
%{_bindir}/idevicescreenshot
%{_bindir}/ideviceenterrecovery
%{_bindir}/idevicedate
%{_bindir}/idevicesetlocation
%{_bindir}/ideviceprovision
%{_bindir}/idevicenotificationproxy
%{_mandir}/man1/idevice_id.1%{?ext_man}
%{_mandir}/man1/idevicebtlogger.1%{?ext_man}
%{_mandir}/man1/idevicecrashreport.1%{?ext_man}
%{_mandir}/man1/idevicedevmodectl.1%{?ext_man}
%{_mandir}/man1/idevicepair.1%{?ext_man}
%{_mandir}/man1/ideviceinfo.1%{?ext_man}
%{_mandir}/man1/idevicesyslog.1%{?ext_man}
%{_mandir}/man1/idevicebackup.1%{?ext_man}
%{_mandir}/man1/idevicebackup2.1%{?ext_man}
%{_mandir}/man1/idevicedebug.1%{?ext_man}
%{_mandir}/man1/idevicedebugserverproxy.1%{?ext_man}
%{_mandir}/man1/idevicediagnostics.1%{?ext_man}
%{_mandir}/man1/ideviceimagemounter.1%{?ext_man}
%{_mandir}/man1/idevicename.1%{?ext_man}
%{_mandir}/man1/idevicescreenshot.1%{?ext_man}
%{_mandir}/man1/ideviceenterrecovery.1%{?ext_man}
%{_mandir}/man1/idevicesetlocation.1%{?ext_man}
%{_mandir}/man1/idevicedate.1%{?ext_man}
%{_mandir}/man1/ideviceprovision.1%{?ext_man}
%{_mandir}/man1/idevicenotificationproxy.1%{?ext_man}

%files -n python3-imobiledevice
%{python3_sitearch}/imobiledevice.so

%changelog
* Fri Nov 22 2024 dmueller@suse.com
- add python3-setuptools for python 3.13 support
* Mon Aug 14 2023 dmueller@suse.com
- Update to version 1.3.0+190git.20230705:
  * tools/idevicecrashreport: Silence compiler warning
  * Silence (v)asprintf related compiler warnings
  * Updated OpenSSL-specific code to use OpenSSL 3.0+ API
  * 3rd_party/libsrp6a-sha512: Updated to work with OpenSSL 3.0+ API
  * 3rd_party/libsrp6a-sha512: Update function definitions to modern style
  * 3rd_party/ed25519: Silence compiler warning about missing return value for fread
  * tools/idevicedebug: Add missing default case for switch statement
  * tools/idevicedevmodectl: Add missing include
  * idevice: Add missing include for Windows
  * idevice: Fix network address handling in other code paths too
  * idevice: Use network addresses as is from what we get from (lib)usbmuxd
- restrict to Cython < 3
* Mon Jun  5 2023 msuchanek@suse.com
- Update to version 1.3.0+179git.20230430:
  * Updated to use latest libplist API changes
  * installation_proxy: Handle BundleIDs in instproxy_client_options_add
  * idevice: Fix connections to <= iOS 5 devices with OpenSSL 3
  * idevicebackup2: Fix missing break in switch case statement
  * tools/ideviceimagemounter: Notify user of missing Developer Mode on iOS 16+
  * tools: Add idevicedevmodectl tool
  * lockdown: Fix error parsing for older iOS versions
  * Support OpenSSL built without OPENSSL_ENGINE
  * idevicedebugserverproxy: Add support for 'qLaunchGDBServer' command of lldb
  * idevice: Fix OpenSSL 3.0 internal error on read timeout
  * tools: Fix idevicebackup2 option parsing for --password option
  * idevicebackup2: Fix option parsing
  * instproxy: Use synchronous mode when callbacks are NULL, as documented
  * Add new idevice_events_subscribe/unsubscribe API with context
  * Initial commit of working packet logger (idevicebtlogger)
  * ideviceinfo: Make sure all error messages go to stderr
  * tools: Use getopt for option parsing in all tools
  * idevice: Fix mistreatment of 0-byte sent cases
  * idevicebackup2: Allow passing backup password via environment variable
  * idevicedebug: Add 'kill' command to kill a (debuggable) app by bundle ID
  * Handle connection failures in debugserver_client_receive_response; also simplify the code
  * Add timeout and interrupt handling to debugserver. Fix debugserver_client_handle_response
  * idevicedebug: Process "Wxx" response as "exited with code xx"
  * idevicecrashreport: Allow filtering crash reports by filename
  * idevicedebugserverproxy: Allow binding to any available port
  * idevicedebug: Gracefully fail on invalid bundle IDs
  * tools: Correct misspelled directionary -> dictionary in function name
  * diagnostics_relay: Check for errors after sending requests to service connection
  * Add support for wireless pairing
  * tools: Print meaningful error messages when service startup fails
  * Add Reverse Proxy implementation
* Wed Jan 19 2022 mgorse@suse.com
- Add python-rpm-macros to BuildRequires (boo#1194755).
* Sat Oct  9 2021 sebix+novell.com@sebix.at
- Update to version 1.3.0+git.20210921:
  * Remove common code in favor of new libimobiledevice-glue
  * tools: idevicebackup2: Exit on service startup failure and improve error messages
  * idevice: Reset receive length variable in internal_ssl_read retry loop and fix wrong variable in debug message
  * lockdown: Get DeviceClass to make sure OS version dependent code is executed correctly
  * Handle error cases in relevant code when retrieving pair record fails
  * common: Return proper error codes from userpref_read_pair_record
  * Add support for MbedTLS
  * idevice: Make sure to handle timeout condition for network connections too
  * installation_proxy: Ignore non-status messages instead of terminating loop
  * mobilesync: Set DeviceLink version to 400 to support iOS 14b4+
  * tools/idevicecrashreport: Fix illegal filenames on Windows
  * tools: Fix entering recovery mode on iOS 14.5+ which now requires a pairing
  * tools: Fix delays in idevicedebugserverproxy when using SSL
  * debugserver: Return success when a receive timed out but actualy bytes have been read
  * idevice: Allow partial reads in idevice_connection_receive_timeout() and handle timeouts more adequate
  * Fixed bytes/strings checks in lockdown.pxi for compatibility with Python2/3
  * Fixed bytes/strings check in imobiledevice.pyx for compatibility with Python2/3
  * Fixed debugserver.pxi PyString_AsString compatibility with Python3
  * Fixed AFC afc.pxi definitions for Python2/3 compatibility. Added missing public method 'remove_path_and_contents'
  * ideviceprovision: Fix date output by adding MAC_EPOCH
  * docs: Improve --quiet command line switch description in idevicesyslog man page
  * idevicescreenshot: Choose a better filename, prevent overwriting existing files
  * idevicedebug: Add --detach option to start an app and exit idevicedebug without killing the app
  * idevicebackup2: Handle DLMessagePurgeDiskSpace by sending back error code
  * idevicebackup2: Update errno to device error mapping
  * idevice: Handle -EAGAIN in case usbmuxd_send() returns it
  * idevicebackup2: Don't fail on restore when source backup doesn't have any application info
* Wed Oct 14 2020 christophe@krop.fr
- Use the new library name in baselibs.conf.
* Thu Sep 24 2020 mpluskal@suse.com
- Remove unnecessary provides/obsoletes
* Tue Sep 22 2020 suse@foomaster.de
- Update to verison 1.3.0+git.20200910
  * Fix service startup for iOS 14b4
  * Add more lockdown error codes
  * Add new lockdownd_pair_with_options() function
  * Make sure sockets only listen locally due to security reasons
  * Plug various memory leaks
  * Store application information in Info.plist using idevicebackup2
  * Various other bugfixes and improvements
* Sun Apr  5 2020 mpluskal@suse.com
- Update to version 1.2.0+git.20200330:
  * Add idevicesetlocation tool
  * debugserver: Fix argv encoding
  * Update debug.c to consistently output to stderr
  * idevicedebug: Rename name-colliding debug_info() to log_debug()
  * debugserver: Fix whitespace error
  * debugserver: Proxy SERVICE_E_TIMEOUT into DEBUGSERVER_E_TIMEOUT
  * introduces optional `idevice_connection_disable_ssl` with ability not to send  SSL shutdown message. As in debugserver this message will be considered as GDB server communication and break things
  * Increase timeout for service receive methods
  * idevicesyslog: Make sure CTRL+C works when waiting for passcode entry
  * configure.ac: Add checks to ensure libusbmuxd is up-to-date
* Sat Mar 14 2020 tchvatal@suse.com
- Fix not needed requires
* Thu Mar 12 2020 tchvatal@suse.com
- Switch python bindings to base on python3
- Update version to 1.2.0+git20200220.3d8d13f:
  * Many fixes all around
  * support for py3
* Tue Jun 12 2018 i@marguerite.su
- update version 1.2.0+git20180427.26373b3
  * Propagate lower level errors to callers instead of returning unknown
  * Added IDEVICE_DEVICE_PAIRED event constant matching the corresponding
  * Define htobe16 if not defined
  * Fix parameter check of instproxy_check_capabilities_match()
  * Avoid double free with OpenSSL 1.1.0 (boo#1103546)
  * Don't use ERR_remove_thread_state() with OpenSSL 1.1.0
  * #ifdef out code which is a no-op with OpenSSL 1.1.0
  * cython: Fix build error after error constant rename
  * gnutls: check for interrupted gnutls_handshake()
  * idevicescreenshot: Detect screenshot image format to determine file extension
  * Add basic mobileactivation service implementation
  * mobileactivation: Add new functions required for drmHandshake / session mode device activation
  * lockdown: Don't explicitly validate pairing unless we're dealing with an older device
  * mobileactivation: Don't convert activation record if it is already passed as PLIST_DATA
  * mobileactivation: Allow passing activation response headers as required for iOS 11.2+
  * lockdown: Plug small memory leak
  * idevicesyslog: Wait for passcode entry on device when required
  * idevicediagnostics: Add HDMI to the list of valid options for diagnostics command
  * idevicediagnostics: Add ioregentry command to query device IORegistry by entry
  * userpref: [GnuTLS] Fix 3.6.0 SHA1 compatibility
  * userpref: [GnuTLS] Use valid serial for >= 3.6.0
  * build: Fix autogen.sh with srcdir != builddir
* Thu Feb  2 2017 i@marguerite.su
- added _service file to clearly show the package origin
* Thu Feb  2 2017 jengelh@inai.de
- SRPM group assignment fix. Trim DLL/library format baggage
  from description.
* Sun Jan 22 2017 i@marguerite.su
- update version 1.2.0+git20170122.45fda81
  * m4: use python-config if available to fix python3 support
    on newer distros
  * lockdown: remove unneeded plist_free() calls since entire dict
    is freed later
  * lockdown: add more error codes
  * add new lockdownd_pair_with_options() function
  * fix installation_proxy when using GnuTLS instead of OpenSSL
  * tools: fix inverted abort condition in idevicecrashreport
  * tools: idevicecrashreport: propertly initialize buffer used
    to check for ping message
  * tools: idevicecrashreport: fix missing 0-term when creating local
    filename
  * make sure sockets only listen locally
  * idevicebackup: fix some timestamps that are relative to the Mac
    epoch instead of Unix one
  * avoid potential NULL pointer dereference (leading to segfault) if
    functions are called w/ null arguments
  * add new functions to get the underlying file descriptor of an
    idevice connection
  * idevicedebug: show error if container info not found
  * diagnostics_relay: plug small memory leak
  * file_relay: plug small memory leak
  * update GnuTLS certificate callback to new API
  * fix SSL version negotiation with newer versions of OpenSSL
  * lockdown: remove unnecessary check for pair record file during
    pairing
  * userpref: remove obsoleted function userpref_has_pair_record()
  * idevice: update GnuTLS code to support iOS 10
  * lockdown: return LOCKDOWN_E_INVALID_HOST_ID when missing pair record
  * idevicebackup2: fix removal of snapshot dir during backup w iOS 10+
  * idevicebackup2: add installed application info to Info.plist
    during backup
  * idevicebackup2: fix assertion occuring when copying non-present MEID
  * idevicebackup2: suppress repeated printing of global status when
    100%% is reached
  * idevicebackup2: use remove_file() wrapper instead of remove()
  * idevicebackup2: don't report an error when file to remove doesn't
    exist
  * idevicebackup2: fix heap buffer out-of-bounds write caused by
    wrong buffer size
  * userpref: [GnuTLS]fix pairing record generation and improve
    error handling
  * idevicebackup2: plug some small memory leaks
  * misagent: add new misagent_copy_all() function (introduced in iOS 9.3)
  * ideviceprovision: use newer API to get list of profiles on iOS 9.3+
  * ideviceprovision: check output directory parameter for 'copy'
    command and return exit code on error
  * ideviceprovision: allow copying single profiles instead of all
  * ideviceprovision: add new remove-all command to remove all installed
    profiles at once
  * idevicebackup2: fix logical bug when checking for success of backup
    operation
  * ideviceprovision: fix ASN1 parsing for large provisioning profiles
  * property_list_service: remove packet length check when receiving
    plist data
- drop libimobiledevice-CVE-2016-5104.patch, upstreamed
- drop libimobiledevice-nosslv3.patch, upstream changed default
  method from SSLv3_method to TLSv1_method.
* Fri May 27 2016 dimstar@opensuse.org
- Add libimobiledevice-CVE-2016-5104.patch: Make sure sockets only
  listen locally (CVE-2016-5104, boo#982014).
* Wed Jul 29 2015 i@marguerite.su
- fix baselibs.conf
* Sat Jul 18 2015 crrodriguez@opensuse.org
- libimobiledevice-nosslv3.patch: In tumbleweed, SSLv3_method
  fails because there is no sslv3 support, use SSLv233_method instead
  to negotiate the highest TLS version available.
* Sun Mar  1 2015 i@marguerite.su
- update version 1.2.0
  * Require autoconf 2.64 or later
  * Remove dev tools, will return either as proper tools or website examples
  * Refactor installation proxy service implementation and normalize code
  * API: Added instproxy_lookup() to efficiently lookup app information
  * API: Added instproxy_check_capabilities_match() to check device capabilities
  * API: Added various instproxy command and status plist getters
  * API: Make debugserver_client_set_ack_mode() public
  * Fix handling of clients reconnecting in idevicedebugserverproxy which
    previously didn't work properly
  * Flush stdout for every line in idevicesyslog
  * Fix shutdown of idevicedebugserverproxy tool which could hang
  * Notify user when erroneously using idevicebackup with iOS 4 or later
  * Enable build of idevicecrashreport on WIN32
  * Fix thread handle leaks on WIN32 adding thread_new and thread_free
  * cython: Add receive/receive_timeout methods for iDeviceConnection to
    receive raw data from a connection
  * cython: Add new FILE_RELAY_E_PERMISSION_DENIED(-6) error
  * API: Refactor lockdown service internal error checking and add a bunch of
    new native errors
  * Convert int16_t macro error types into enum within common module, too
  * Add new "idevicenotificationproxy" tool to post or observe notifications
  * Fix overlong blocking in np_client_free()
  * Improve maintainability and Requires of pkg-config file
  * API: Add new LOCKDOWN_E_SERVICE_LIMIT error to detect service limit states
  * API: Remove const argv requirement for debugserver_command_new
  * cython: Add get_path_for_bundle_identifier() method to
    InstallationProxyClient
  * cython: Add DebugServerClient class to communicate with debugserver
  * Comply to strict function prototypes by using (void) instead of just ()
  * Fix notification proxy shutdown process which was incorrectly implemented
  * Fix linking problems on OS X
  * Fix missing debug output which broke with the last release
  * Unify and improve various debug messages
  * Fix re-pairing if pairing with existing pair record failed initially
  * Skip printing long plist (16kb+) files to prevent excessive debug output
  * Move a few common helpers from backup tools to common utility helper code
  * Remove incorrect flags from afc_file_open() documentation
  * Fix various memory leaks
* Fri Oct 17 2014 m.szulecki@libimobiledevice.org
- Update to version 1.1.7
  * Fix broken app args, environment handling and memory leaks in idevicedebug
  * Make all tools print an error if lockdown connection fails
  * Convert int16_t macro error types into enum for better type-checking and
  * for various debugging benefits
  * Avoid exporting non-public symbols for better ABI stability
  * Fix failing backup process for devices having a passcode set and entering
  * lock state during the process in idevicebackup2
  * API: Added lockdownd_start_service_with_escrow_bag()
  * API: Added afc_remove_path_and_contents() for recursive deletion
  * Fix last memory leak with OpenSSL through proper library deinitialization
  * Add new idevicedebug tool to interact with debugserver on a device
  * API: Add debugserver service implementation
  * Handle new PermissionDenied error of file_relay due new security in iOS 8+
  * Fix retry loop problem when device requests 0 files in idevicebackup2
  * Add trust dialog related error codes to Cython bindings
  * Fix various memory leaks in AFC implementation
  * Fix disk image upload with latest iOS 8 in ideviceimagemounter
  * Add new "dump" command to print information about a provisioning profile in
  * ideviceprovision
  * Refactor plist print helper code and move it into common module for better
  * reuse accross the tools
  * Do not crash if retrieving the system buid fails
  * API: Make generic "propery_list_service_client" public
  * Moved doc comments from private to public headers
  * Fix possible segfault when using lockdownd_get_value() due to always
  * returning success
  * Do not read files entirely into memory during restore in idevicebackup
  * Plug a few memory leaks and fix invalid password check in idevicebackup2
  * Add support for file sizes > 4GB on Win32 in idevicebackup2
  * Fix declaration for DllMain on Win32
  * Silence various compiler warnings
  * Fix assert within pairing logic
* Mon Jul 14 2014 i@marguerite.su
- add hard depedency on libplist-devel for libimobiledevice-devel
  * fix build for openSUSE Factory
  * I don't know why it didn't automatically requires it.
* Mon Jun 16 2014 i@marguerite.su
- Update to version 1.1.6
  * Remove segmentation code from afc_file_read() to provide raw interface and
    more control to API consumer I/O logic
  * Implement global thread safe library initialization, especially to control
    SSL backend lifecycle
  * Major refactoring of pair record code and logic to use new usbmuxd pair
    record management interface
  * Replace user level with system wide pair record file handling
  * Bump dependency to libplist 1.11 and remove use of "plist_dict_insert_item"
  * Bump dependency to libusbmuxd 1.0.9
  * Finish pair record and trust dialog handling for iOS 7+
  * Improve AFC write performance and memory usage
  * Add support for custom output filename to idevicescreenshot
  * Fix detection and compilation for Python 3.x
  * API: Added file_relay_request_sources_timeout()
  * Fix broken HouseArrestClient class in cython bindings
  * Add new idevicecrashreport tool to retrieve crash reports and logs from a
    device
  * Prevent "Failed to restart/shutdown device" messages in idevicediagnostics
  * Link against ws2_32.dll on Win32
  * Add support for iOS 7+ disk image mounting to ideviceimagemounter
  * Add new idevicename tool to get or set the device name
  * Allow unbacking of encrypted backups with a given password to idevicebackup2
  * Remove sending "Goodbye" request on lockdown
  * Add support for newer PLIST_REAL based time type to idevicedate
  * Add note about setting time not working on iOS 6+ to idevicedate
  * Handle partial SSL reads correctly now to prevent random crashes
  * Fix duplicated output in ideviceinfo output
  * Remove a bunch of dead code
  * Fix deprecated OpenSSL "RSA_generate_key" with "RSA_generate_key_ex" which
    is available since OpenSSL 0.9.8 (July 2005)
  * Improve debug messages
  * Enforce "-fsigned-char" to fix issues on embedded platforms
  * Fix compilation with Clang/LLVM
  * Avoid versioning for shared library on Win32
  * Add experimental support for controlling cloud backup mode to idevicebackup2
  * Save EscrowBag when starting service for automatic unlocking in pair record
  * Remove pairing logic which is obsoleted by usbmuxd's preflight handler
  * Fix shutdown of SSL connection to be correct and no longer generate errors
    on device
  * Add support for GnuTLS 3.x and fix broken GnuTLS backend
  * Add extensions to generated certificates to match native ones
  * Add "systembuid" command to idevicepair
  * Allow starting service without the need for a running SSL session
  * Refactor more code into common module
  * Add option to filerelaytest to specify a source to request
  * Fix support for partial messages in webinspector implementation
  * Implement support for encrypted backups in idevicebackup2
  * API: Export SSL control functions for idevice_connection_t
  * API: Make generic service client public to allow external service
    implementations
  * Implement *_start_service() helper for easier creation of service clients
  * Add public *_SERVICE_NAME defines for each service
  * Fix a great bunch of memory leaks after intensive valigrind session
  * Security: Fix insecure use of the /tmp directory (CVE-2013-2142)
  * A bunch of memory leak fixes
  * Python: Various fixes and support for "with" statement for AfcFile class
  * Python: Add Afc2Client class to allow jailbroken filesystem access
  * Fix linking issue with newer libtool as reported for Ubuntu
  * Fix stuck thread in idevicesyslog which broke quit from within the tool
  * Add syslog_relay service implementation and use it in idevicesyslog
  * API: Add instproxy_client_get_path_for_bundle_identifier() helper
  * API: Add afc_dictionary_free() helper
  * Move thread, socket, debug and userpref code to "common" source directory
    in order to improve code reuse
  * Fix broken byte order detection in configure.ac which could lead to broken
    AFC protocol communication on platforms without endian.h (Raspberry PI)
* Sat Jul 20 2013 dimstar@opensuse.org
- Mark docs/html as %%doc, not %%docdir: docdir only 'flags' a
  directory to contain documentation, but does not actuall ADD the
  documentation, which is clearly not the intent here.
  Additionally, RPM 4.11 no longer allows %%docdir to be used on
  relative paths (as it's meant to flag directories in $DESTDIR).
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 1.1.5:
  + An improved idevicebackup2 tool.
  + Various new tools.
  + Better cross-platform building.
  + Crash fixes.
  + iOS 6+ compatibility fixes.
  + An important API change related to service lifecycle
    management.
- Drop libimobiledevice-cython1.16-detection.patch: fixed upstream.
- Drop libimobiledevice-segfault-fix.patch: fixed upstream.
- Change _lname defines to libimobiledevice4, following upstreams
  soname change.
- Update baselibs.conf to follow the soname change.
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Jan 18 2013 dimstar@opensuse.org
- Disable python bindings (using with_python defines):
  python-cython 0.17 became even stricter and the bindings
  currently don't build, but they are also not used by anything at
  this moment (bnc#796133).
* Mon Jul  9 2012 sbrabec@suse.cz
- Fix segfault without $XDG_CONFIG_HOME and $HOME set
  (bnc#768537, libiphone#273).
* Wed Jun 20 2012 dimstar@opensuse.org
- Add libimobiledevice-cython1.16-detection.patch: Fix build with
  Cython 1.16.
* Mon Apr  9 2012 opensuse@sukimashita.com
- Allow compilation on 11.4 by disabling cython bindings
* Mon Apr  9 2012 opensuse@sukimashita.com
- Update to 1.1.4:
  - Fix a bug in idevicesyslog causing the connection to close after timeout
  - Bump soname revision
  - Bump libusbmuxd dependency to 1.0.8
  - Fix reading from syslog_relay and remove null characters
  - Relicense ideviceimagemounter and idevicescreenshot to LGPL
  - Fix a crash when using restored_client_free()
  - API: Add sbservices_get_interface_orientation()
  - Update man pages and code comments for documentation
  - Minor cleanup
  - Add Python bindings generated by Cython
  - Bump libplist requirement to latest 1.8
  - Add support for OpenSSL with fallback to GNUTLS
  - Improvements and various fixes for Win32 and OS X build
  - Remove glib dependency
  - Improve restored implementation
  - Fix various memory leaks
  - Fix support for iOS 5 and later
- Remove swig patch as bindings have been removed
- Remove gstatbuf patch as it is obselete now
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jul 26 2011 coolo@novell.com
- add baselibs.conf for libgpod to use
* Thu May 26 2011 idonmez@novell.com
- Add libimobiledevice-swig-2x.patch: support swig 2.x
* Thu May 12 2011 dimstar@opensuse.org
- Change License tags to LGPLv2.1+ and GPLv2+ (Some of the tools
  are GPLv2+) and add COPYING.LESSER to the library package.
* Thu Apr 28 2011 opensuse@sukimashita.com
- Update to 1.1.1:
  + Add new idevicebackup2 tool for full backup and restore
    support on iOS 4+
  + Add a workaround for a bug in iOS 4.3 affecting
    lockdown_get_value() which most prominently affected libgpod,
    gvfs, ideviceinfo and some other tools
  + Read ProxyDeath message to preventing obsolete messages in
    device syslog
  + Rework SWIG detection and includes
  + Add new idevicedate tool to get or set the clock on iDevices
  + API: Add mobilesync_clear_all_records_on_device()
  + API: Change device_link_service_disconnect() to accept a
    message
  + Add manpages for ideviceenterrecovery, idevicepair,
    idevicebackup2 and idevicedate
  + Add missing libgen.h include to silence compiler warnings
  + Fix a segfault that might occur if locally stored certs
    could not be read
  + Fix various memory leaks
  + Update documentation
- Add libimobiledevice-gstatbuf-fix.patch to fix build of oS < 11.4
* Mon Feb 28 2011 fcrozat@novell.com
- Update to 1.1.0:
  + Note that this is a development release, which means:
  - Python Bindings will get refactored completely
  - API is UNSTABLE
  + Implement restoring backups using idevicebackup
  + Allow connecting without pairing using "ideviceinfo -s"
  + Add ideviceenterrecovery tool
  + Add mobilesync service implementation
  + Add restored service implementation for restore mode
  + Add home_arrest service implementation for document sharing
  + Add API afc_client_new_from_connection()
  + Support to fetch wallpaper in sbservices
  + Support for formatVersion 2 of iOS 4+ in sbservices
  + Add new lockdownd domains to ideviceinfo
  + Give the device time to prepare backup data to prevent abort
  + Improve idevicebackup output
  + notification_proxy fixes and new notification type
  + Silence some 64bit compiler warnings
  + Fix various memory leaks
  + Update documentation
- Drop 0b40ddb1f41c94a3ee58abc6326e59d65662e5c7.patch: fixed
  upstream.
* Wed Dec 29 2010 andreas.hanke@gmx-topmail.de
- backport commit 0b40ddb1f41c94a3ee58abc6326e59d65662e5c7 to fix build
* Wed Dec  8 2010 cristian.rodriguez@opensuse.org
- disable silent rules, breaks post build checks.
- fix -devel package dependencies
* Sat Nov 27 2010 opensuse@sukimashita.com
- Update to 1.0.4:
  * Fix a possible crash in lockdownd_client_new_with_handshake()
  * Do not not check for Swig/Python if --without-swig is set
  * Fail with an error message if libgcrypt is not found
  * Pass host certificate with GNUTLS correctly
  * Fix connecting to iOS 4.2.1+ devices
* Tue Oct  5 2010 opensuse@sukimashita.com
- Update to 1.0.3:
  * Terminate idevicesyslog on receive errors (like device unplug)
  * Bugfixes for idevicebackup tool
  * Hopefully the last fixes for big endian machines
  * Build fixes for FreeBSD Python support
  * Fix build on Mac OS X
* Sun Jun 20 2010 opensuse@sukimashita.com
- Update to 1.0.2:
  * Backport new idevicepair tool to manage pairings
  * Fix a bug causing bad backup data
  * Silence 64bit compiler warnings
  * Plug some memory leaks
* Wed May 12 2010 opensuse@sukimashita.com
- Update to 1.0.1:
  * Cleanup includes of files
  * Use glib instead of netinet for endianess
  * Fix installation_proxy not adding client options correctly
  * idevicebackup: better handle broken or missing plist files
  * Fix some memory leaks in pairing/handshake process
  * Fix label not being used in lockdownd_client_new()
  * Update AUTHORS, README and installation instructions
* Tue Mar 23 2010 opensuse@sukimashita.com
- Update to 1.0.0:
  * Update and fix documentation for full coverage
  * Add man pages for tools
  * Extend mobilebackup interface
  * Add user data argument to notification callback function
  * Fix broken Python bindings
  * Add Python bindings for notification proxy interface
  * Add screenshotr interface and tool
  * Add mobile_image_mounter interface and tool
  * Remove HAL fdi rules
* Tue Feb  2 2010 opensuse@sukimashita.com
- Rename package to libimobiledevice
- Update to 0.9.7:
  * Project renamed to libimobiledevice
  * Add soname versioning for future releases
  * Fix regression causing never paired devices to not work by adding
    auto-pairing for devices in lockdownd_client_new_with_handshake
  * Add file_relay service implementation and dev test tool
  * Minor device link service fixes
  * New idevicebackup tool with support for full and incremental backups
  * Add mobilebackup service implementation
* Sat Jan 23 2010 opensuse@sukimashita.com
- Update to 0.9.6:
  * Minor public API changes to prepare for 1.0 release:
  - lockdownd_client_new -> lockdownd_client_new_with_handshake
  - fooservice_recv -> fooservice_receive
  - iphone_device_send/_recv -> iphone_connection_send/_receive
  * Rename some code for consistency
  * Refactor pairing to allow custom pair records
  * Move SSL handling out of lockdownd code
  * Refactor lockdown session handling code
  * Remove debug mask support
  * No longer do a full lockdown handshake on client_new
  * Refactor debug code to be consistent and easier to use
  * Run validate_pair by default during lockdown handshake
  * Allow retrieving the type for lockdown query_type request
  * Add new property_list_service and device_link_service abstractions
  * Detect pairing failure due to having a password set on the device
  * Implement lockdown phone activation and deactivation
  * Fix iphoneinfo not printing values in key/value mode
  * Implement lockdownd_unpair() request
  * Add more notification ids and lockdown domains
  * Implement label support for lockdown requests
  * Add new installation_proxy interface
  * Add new sbservices interface
  * Implement lockdownd_validate_pair() request
  * Add endian safety to AFC
  * Make lockdown sessions without SSL work
  * Fix linking on Mandriva Linux
  * Minor bugfixes and documentation updates
* Tue Nov 24 2009 opensuse@sukimashita.com
- Update to 0.9.5:
  * Updated to the latest libplist 0.16 API
  * Fixed various minor leaks and issues
  * Updated Python bindings and module name
* Thu Oct 29 2009 opensuse@sukimashita.com
- Update to 0.9.4:
  * Update to libplist 0.15 API rework
  * Update Python bindings
  * Bufixes around usbmuxd daemon usage
  * Use automake 1.11 silent rules if available
  * Various bugfixes
* Thu Aug  6 2009 opensuse@sukimashita.com
- Update to 0.9.3:
  * Migrate to use the new usbmuxd daemon
  * Refactor whole API
  * Add iPhone 3GS support
  * Add hard/symlink support for AFC
  * New iphone_id tool to list connected devices and get the device
    name
  * iphoneinfo now allows plist/xml output and queries by
    domain/key
  * Fix a lot of bugs/crashes, compiler warnings and comments
  * Bump libplist requirement to 0.13 and remove deprecated code
* Wed May 13 2009 opensuse@sukimashita.com
- Update to 0.9.1:
  * Fix make distcheck
  * Bump libplist requirement to 0.12 and remove deprecated code
  * A bunch of autotools fixes
- Include iphoneinfo and iphonesyslog tools in packages
- Removed upstreamed patches
* Sun May 10 2009 opensuse@sukimashita.com
- Update to 0.9.0:
  * Fix pkg-config dependancies
  * Fix Python binding generation
  * AFC cleanup and improved error handling
  * Add support for the notification proxy service
  * Add tools to show device information and relay syslog
  * More robust pairing implementation
  * Remove libiphone-initconf, SSL implementation handles it at
    runtime now
  * Fix receive of plists larger than a packet
  * Return an error if failed to start a service on the device
  * Fix usb enumeration
  * Fix udev rule to catch usb hubs, too
  * Add large file support
  * Move out plist handling into libplist and depend on it
  * Add Python bindings
  * Lots of bugfixes
- Remove upstreamed patches
* Sat Apr 11 2009 opensuse@sukimashita.com
- Update to latest git HEAD
  * Use udev to set usb configuration; iphone kmod is obsolete now
  * Remove HAL mounting
  * Bugfixes
* Sat Apr  4 2009 opensuse@sukimashita.com
- Rename source package to libiphone
* Sat Jan 31 2009 opensuse@sukimashita.com
- Initial package created
